@@ -1,9 +1,12 @@
 mod card;
 mod digu;
+pub mod game;
+mod stack;
 
 #[cfg(test)]
 mod tests {
     use super::card::{Card, Value};
+    use super::digu::score_hand;
 
     #[test]
     fn check_first_card() {
@@ -32,4 +35,12 @@ mod tests {
             assert_eq!(card.index(), i);
         }
     }
+
+    #[test]
+    fn evaluate_preset_hand() {
+        let hand = [0, 1, 2, 3, 4, 5, 6, 7, 9, 10];
+        let outcome = score_hand(&hand);
+        assert_eq!(outcome.digs.len(), 2);
+        assert_eq!(outcome.score, 20);
+    }
 }
